@@ -1,12 +1,4 @@
 
-from diagrams import Diagram, Cluster
-
-from diagrams.aws.management import Organizations, OrganizationsAccount, OrganizationsOrganizationalUnit
-
-with Diagram("Organizations-State", show=False, direction="TB"):
-    ou = OrganizationsOrganizationalUnit("OU")
-    oa = OrganizationsAccount("Account")
-
     with Cluster('Organizations'):
 
         oo = Organizations('o-9tlhkjyoii\n029921763173\nr-w3ow')
